EarthShape

Struct EarthShape 

pub struct EarthShape {
    pub shape: u8,
    pub spherical_earth_radius_scale_factor: u8,
    pub spherical_earth_radius_scaled_value: u32,
    pub major_axis_scale_factor: u8,
    pub major_axis_scaled_value: u32,
    pub minor_axis_scale_factor: u8,
    pub minor_axis_scaled_value: u32,
}

Fields

shape: u8

Shape of the Earth (see Code table 3.2).

spherical_earth_radius_scale_factor: u8

Scale factor of radius of spherical Earth.

spherical_earth_radius_scaled_value: u32

Scaled value of radius of spherical Earth.

major_axis_scale_factor: u8

Scale factor of major axis of oblate spheroid Earth.

major_axis_scaled_value: u32

Scaled value of major axis of oblate spheroid Earth.

minor_axis_scale_factor: u8

Scale factor of minor axis of oblate spheroid Earth.

minor_axis_scaled_value: u32

Scaled value of minor axis of oblate spheroid Earth.

Implementations

Source

impl EarthShape

pub fn radii(&self) -> Option<(f64, f64)>