SimplePacking

Struct SimplePacking 

pub struct SimplePacking {
    pub ref_val: f32,
    pub exp: i16,
    pub dec: i16,
    pub num_bits: u8,
}

Fields

ref_val: f32

Reference value (R) (IEEE 32-bit floating-point value).

exp: i16

Binary scale factor (E).

dec: i16

Decimal scale factor (D).

num_bits: u8

Number of bits used for each packed value for simple packing, or for each group reference value for complex packing or spatial differencing.