ComplexPacking

Struct ComplexPacking 

pub struct ComplexPacking {
    pub group_splitting_method: u8,
    pub missing_value_management: u8,
    pub primary_missing_value: u32,
    pub secondary_missing_value: u32,
    pub num_groups: u32,
    pub group_width_ref: u8,
    pub num_group_width_bits: u8,
    pub group_len_ref: u32,
    pub group_len_inc: u8,
    pub group_len_last: u32,
    pub num_group_len_bits: u8,
}

Fields

group_splitting_method: u8

Group splitting method used (see Code table 5.4).

missing_value_management: u8

Missing value management used (see Code table 5.5).

primary_missing_value: u32

Primary missing value substitute.

secondary_missing_value: u32

Secondary missing value substitute.

num_groups: u32

NG - number of groups of data values into which field is split.

group_width_ref: u8

Reference for group widths (see Note 12).

num_group_width_bits: u8

Number of bits used for the group widths (after the reference value in octet 36 has been removed).

group_len_ref: u32

Reference for group lengths (see Note 13).

group_len_inc: u8

Length increment for the group lengths (see Note 14).

group_len_last: u32

True length of last group.

num_group_len_bits: u8

Number of bits used for the scaled group lengths (after subtraction of the reference value given in octets 38-41 and division by the length increment given in octet 42).